@@ -19,7 +19,7 @@ C Client Library for memcached (libmemcached, -lmemcached)
   char *memcached_get (memcached_st *ptr,
                        char *key, size_t key_length,
                        size_t *value_length, 
-                       uint16_t *flags,
+                       uint32_t *flags,
                        memcached_return *error);
 
   memcached_return
@@ -31,7 +31,7 @@ C Client Library for memcached (libmemcached, -lmemcached)
                        char *master_key, size_t master_key_length, 
                        char *key, size_t key_length, 
                        size_t *value_length, 
-                       uint16_t *flags,
+                       uint32_t *flags,
                        memcached_return *error);
 
   memcached_return 
@@ -43,21 +43,20 @@ C Client Library for memcached (libmemcached, -lmemcached)
   char *memcached_fetch (memcached_st *ptr,
                          char *key, size_t *key_length, 
                          size_t *value_length,
-                         uint16_t *flags, 
+                         uint32_t *flags, 
                          memcached_return *error);
   memcached_return 
   memcached_fetch_execute(memcached_st *ptr, 
                           unsigned int (*callback[])(memcached_st *ptr, memcached_result_st *result, void *context),
                           void *context,
-                          unsigned int number_of_callbacks
-                         )
+                          unsigned int number_of_callbacks);
 
 =head1 DESCRIPTION
 
 memcached_get() is used to fetch an individual value from the server. You
 must pass in a key and its length to fetch the object. You must supply
 three pointer variables which will give you the state of the returned
-object.  A uint16_t pointer to contain whatever flags you stored with the value,
+object.  A uint32_t pointer to contain whatever flags you stored with the value,
 a size_t pointer which will be filled with size of of the object, and a
 memcached_return pointer to hold any error. The object will be returned
 upon success and NULL will be returned on failure. 
@@ -76,7 +75,7 @@ memcached_fetch() is used to fetch an individual value from the server.
 memcached_mget() must always be called before using this method.  You
 must pass in a key and its length to fetch the object. You must supply
 three pointer variables which will give you the state of the returned
-object.  A uint16_t pointer to contain whatever flags you stored with the value,
+object.  A uint32_t pointer to contain whatever flags you stored with the value,
 a size_t pointer which will be filled with size of of the object, and a
 memcached_return pointer to hold any error. The object will be returned
 upon success and NULL will be returned on failure. 
@@ -90,8 +89,8 @@ if you do not pass one to the function.
 memcached_fetch_execute() is a callback function for result sets. Instead
 of returning the results to you for processing, it passes each of the
 result sets to the list of functions you provide. It passes to the function
-a memcached_st that can be cloned for use in called the cluster (it can not 
-be used directly). It also passed a result set which does not need to be freed.
+a memcached_st that can be cloned for use in the called function (it can not 
+be used directly). It also passes a result set which does not need to be freed.
 Finally it passes a "context". This is just a pointer to a memory reference
 you supply the calling function. Currently only one value is being passed
 to each function call. In the future there will be an option to allow this
